# Server Integrations

These guides will cover how to integrate Panel applications with various external frameworks such as Django, FastAPI and Flask.

::::{grid} 1 3 3 3
:gutter: 1 1 1 2

:::{grid-item-card} Flask
:link: flask
:link-type: doc

Discover to run Panel applications alongside an existing Flask server.

![Flask Logo](../../_static/logos/flask.png)
:::

:::{grid-item-card} FastAPI
:link: FastAPI
:link-type: doc

Discover to run Panel applications alongside an existing FastAPI server.

![FastAPI Logo](../../_static/logos/fastapi.png)
:::

:::{grid-item-card} Django
:link: Django
:link-type: doc

Discover to run Panel applications on a Django server (replacing the standard Tornado based server).

![Django Logo](../../_static/logos/django.png)
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

flask
FastAPI
Django
```
